Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BaseSpec ¶
type BaseSpec struct {
Debug bool `default:"false" help:"set debug mode (default: false)"`
SentryDSN string `help:"sentry dsn key"`
IsProd bool `` /* 142-byte string literal not displayed */
Local bool `envconfig:"local" default:"false" help:"setting local to true, enables human readable logging"`
MetricsPort int `envconfig:"metricsPort" default:"8080" help:"the metric server port (default: 8080)"`
}
BaseSpec stores all common service variables
type GoogleImpersonationSpec ¶
type GoogleImpersonationSpec struct {
User string `envconfig:"google_user" required:"true" help:"impersonation user for the google api"`
ServiceAccount string `envconfig:"google_application_credentials" required:"true" help:"path to google service account file"`
}
GoogleImpersonationSpec stores a ServiceAccount and a User field for Google Auth with impersonation
type GoogleSpec ¶
type GoogleSpec struct {
User string `envconfig:"google_user" required:"false" help:"impersonation user for the google api"`
ServiceAccount string `envconfig:"google_application_credentials" required:"true" help:"path to google service account file"`
}
GoogleSpec stores a ServiceAccount and an optional User field for Google Auth
Click to show internal directories.
Click to hide internal directories.